Setup
=====

The Adversarial Robustness Toolbox is designed to run with Python 3.

Installation with `pip`
-----------------------

The library can be installed from the PyPi repository using `pip`:

.. code-block:: bash

   pip install adversarial-robustness-toolbox

Manual installation
-------------------

The most recent version of ART, can be downloaded or cloned from the repository:

.. code-block:: bash

   git clone https://github.com/IBM/adversarial-robustness-toolbox

Install ART with the following command from the project folder `art`:

.. code-block:: bash

   pip install .

ART provides unit tests that can be run with the following command:

.. code-block:: bash

   bash run_tests.sh
